@@ -2,19 +2,20 @@ package controllers
 
 import (
 	"github.com/Mmx233/BitSrunLoginGo/global"
+	"github.com/Mmx233/BitSrunLoginGo/util"
 	BitSrun "github.com/Mmx233/BitSrunLoginGo/v1"
 	"github.com/Mmx233/BitSrunLoginGo/v1/transfer"
+	"net"
 )
 
-func Login(output bool, skipCheck bool) error {
+// Login 登录逻辑
+func Login(localAddr net.Addr) error {
 	return BitSrun.Login(&srunTransfer.Login{
-		Demo:     global.Config.Settings.DemoMode,
-		OutPut:   output,
-		CheckNet: !skipCheck,
-		Timeout:  global.Config.Settings.Timeout,
+		Https: global.Config.Settings.Basic.Https,
 		LoginInfo: srunTransfer.LoginInfo{
 			Form: &global.Config.Form,
 			Meta: &global.Config.Meta,
 		},
+		Client: util.HttpTools(localAddr).Client,
 	})
 }
