@@ -5,13 +5,16 @@ import (
 )
 
 var Flags struct {
-	Path          string
+	//配置文件路径
+	Path string
+	//daemon模式内置标记
 	RunningDaemon bool
-	Daemon        bool
+	//强制daemon
+	Daemon bool
 }
 
 func initFlags() {
-	flag.StringVar(&Flags.Path, "config", "Config.json", "config path")
+	flag.StringVar(&Flags.Path, "config", "Config.yaml", "config path")
 	flag.BoolVar(&Flags.RunningDaemon, "running-daemon", false, "")
 	flag.BoolVar(&Flags.Daemon, "daemon", false, "")
 	flag.Parse()
